@@ -64,7 +64,12 @@ MYPKGOPTIONS <- settings::options_manager(
 
     return(out)
 
-  }
+  },
+  indent_character_Word = "    ",
+  indent_character_Latex = "\\quad",
+  indent_character_HTML = " &emsp; ",
+  indent_character_Console = "    ",
+  indent_character_markdown = "&nbsp;&nbsp;&nbsp;&nbsp;"
 
 
 )
@@ -194,6 +199,9 @@ MYPKGOPTIONS <- settings::options_manager(
 #'    \item{\code{modifiy_colnames_without_alias}}{: A function with one argument \code{x} and \code{...} returning a character.
 #'    This functions is called by \code{create_alias_mapping} on the columns that have \code{is.NULL(get_alias(x))}.
 #'    Replaces underscores by blanks and then calls \code{\link[base]{trimws}}. }
+#'
+#'    \item{\code{indent_character}}{: A Character with length 1. Passed to \code{indent_data_frame}. Every option of \code{format_to}
+#'    has a corresponding indent_character. See the help of \code{atable} for these options. }
 #' }
 #'
 #' @examples
